@@ -52,6 +52,11 @@ int get_cpu_info(cpu_info_t *cpu_info) {
     if (!strncmp(model_string,"NEC",3)) {
        sscanf(model_string,"%s %s",throw_away,cpu_info->chip_type);
     }
+    else 
+    if (!strncmp(model_string,"MIPS",4)) {
+       sscanf(model_string,"%s %s",throw_away,cpu_info->chip_type);	
+    }
+   
     else {
        sscanf(model_string,"%s",cpu_info->chip_type);  
     }
