@@ -60,17 +60,32 @@ int get_cpu_info(cpu_info_t *cpu_info) {
        strncpy(cpu_info->chip_type,"G3",3);	    
     }
    
+    if (strstr(model_string,"750FX")!=NULL) {
+       strncpy(cpu_info->chip_type,"G3",3);	    
+    }
+   
    
     if (strstr(model_string,"7400")!=NULL) {
        strncpy(cpu_info->chip_type,"7400",5);
     }
  
    
+       /* There should be a way to figure out */
+       /* G4/G3 more efficiently than this    */
     if (strstr(model_string,"7410,")!=NULL) {
        strncpy(cpu_info->chip_type,"G4",3);
     }
    
+    if (strstr(model_string,"7455")!=NULL) {
+       strncpy(cpu_info->chip_type,"G4",3);
+    }
    
+       /* I have a powerbook now too ;) */
+    if (strstr(model_string,"7457")!=NULL) {
+       strncpy(cpu_info->chip_type,"G4",3);
+    }
+   
+	
     if (!strncmp(model_string,"PowerPC",7)) {
        sscanf(model_string,"%s %s",throw_away,cpu_info->chip_type);
     }
