@@ -9,7 +9,7 @@ int linux_detect_arch(void) {
  
     /* Yes this is a bit messy, but it cleans up the makefile a bit *\
     \* The C-Preproccessor can be out friend ;)                     */
-
+   
 /*   return ARCH_HPPA; */
       
 #if defined(__alpha__)
@@ -20,7 +20,7 @@ int linux_detect_arch(void) {
     return ARCH_CRIS;
 #elif defined(__ia64__)
     return ARCH_IA64;
-#elif defined(i386)
+#elif (defined(i386) || defined(__x86_64__))
     return ARCH_IX86;
 #elif (defined(mc68000) || #cpu(m68k))
     return ARCH_M68K;
