@@ -1,5 +1,5 @@
 /*-------------------------------------------------------------------------*\
-  LINUX LOGO 4.07 - Creates Nifty Logo With System Info - 23 January 2003
+  LINUX LOGO 4.09 - Creates Nifty Logo With System Info - 17 March 2004
  
     by Vince Weaver (vince@deater.net, http://www.deater.net/weave )
 		     
@@ -22,7 +22,7 @@
 #include "i18n.h"
 
 #define ESCAPE '\033'
-#define VERSION "4.07"
+#define VERSION "4.09"
 
 #include "sysinfo.h"
 #include "linux_logo.h"
@@ -33,7 +33,7 @@
 #include "defaults.h"
 
     /* See defaults.h when setting this */
-#if (USE_I8N==0)
+#if (USE_I18N==0)
 #undef _(string)
 #define _(string) string
 #endif
@@ -326,7 +326,7 @@ void help_message(char *binname, char full)
     printf("         [-d]     -- disable \"prettying\" of output\n");
     printf("         [-D file]-- use custom logo from \"file\"\n"); 
     printf("         [-e file]-- Use \"file\" instead of /proc/cpuinfo [for "
-	   "debugging\n");
+	   "debugging]\n");
     printf("         [-f]     -- force the screen clear before drawing\n");
     printf("         [-F format] Format output.  See README.\n");
     printf("      B  [-g]     -- give system info only\n");
@@ -611,12 +611,13 @@ int main(int argc,char **argv)
     int ignore_config_file=0;
     int old_optind,old_opterr,old_optopt,string_size;
     char *tempst;
-   
+
+#ifndef __FreeBSD__  
        /* i18n */
     setlocale(LC_ALL,"");
     textdomain("linux_logo");
     bindtextdomain("linux_logo", "/usr/lib/locale");
-   
+#endif   
        /* Set some defaults */
     setup_info(&settings); 
     
